==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/sk_SK.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Úložisko nie je platné",
    "Unknown error" : "Neznáma chyba",
    "All files" : "Všetky súbory",
    "Saved" : "Uložené",
    "File could not be found" : "Súbor nenájdený",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Favorites" : "Obľúbené",
    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť adresár \"{dir}\"",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Uploading..." : "Nahrávam...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Opustenie stránky zruší práve prebiehajúce odosielanie súboru.",
    "Actions" : "Akcie",
    "Download" : "Sťahovanie",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Disconnect storage" : "Odpojiť úložisko",
    "Unshare" : "Zrušiť zdieľanie",
    "Files" : "Súbory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrať",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "Invalid path" : "Neplatná cesta",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť „{file}“, cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť „{file}“",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\"" : "Nemožno premenovať súbor \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nemožno vytvoriť súbor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nemožno vytvoriť súbor \"{file}\", lebo už existuje",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov"],
    "New" : "Nový",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'"],
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "Folder" : "Priečinok",
    "New folder" : "Nový priečinok",
    "{newname} already exists" : "{newname} už existuje",
    "Upload" : "Nahrať",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Obmedzte upozornenia na vytvorenie a zmeny na vaše <strong>obľúbené súbory</strong> <em>(Len streamy)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "You created %1$s" : "Vytvorili ste %1$s",
    "%2$s created %1$s" : "%2$s vytvoril %1$s",
    "%1$s was created in a public folder" : "%1$s vytvorený vo verejnom priečinku",
    "You changed %1$s" : "Zmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s zmenil %1$s",
    "You deleted %1$s" : "Bol zmazaný %1$s",
    "%2$s deleted %1$s" : "%2$s zmazal %1$s",
    "You restored %1$s" : "Bol obnovený %1$s",
    "%2$s restored %1$s" : "%2$s obnovil %1$s",
    "Changed by %2$s" : "Zmenené používateľom %2$s",
    "Deleted by %2$s" : "Vymazané používateľom %2$s",
    "Restored by %2$s" : "Obnovené používateľom %2$s",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "File handling" : "Nastavenie správania sa k súborom",
    "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
    "max. possible: " : "najväčšie možné:",
    "Save" : "Uložiť",
    "Settings" : "Nastavenia",
    "Show hidden files" : "Zobraziť skryté súbory",
    "WebDAV" : "WebDAV",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "No favorites" : "Žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/sk_SK.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Úložisko nie je platné",
    "Unknown error" : "Neznáma chyba",
    "All files" : "Všetky súbory",
    "Saved" : "Uložené",
    "File could not be found" : "Súbor nenájdený",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Favorites" : "Obľúbené",
    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť adresár \"{dir}\"",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Uploading..." : "Nahrávam...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Opustenie stránky zruší práve prebiehajúce odosielanie súboru.",
    "Actions" : "Akcie",
    "Download" : "Sťahovanie",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Disconnect storage" : "Odpojiť úložisko",
    "Unshare" : "Zrušiť zdieľanie",
    "Files" : "Súbory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrať",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "Invalid path" : "Neplatná cesta",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť „{file}“, cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť „{file}“",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\"" : "Nemožno premenovať súbor \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nemožno vytvoriť súbor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nemožno vytvoriť súbor \"{file}\", lebo už existuje",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov"],
    "New" : "Nový",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'"],
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "Folder" : "Priečinok",
    "New folder" : "Nový priečinok",
    "{newname} already exists" : "{newname} už existuje",
    "Upload" : "Nahrať",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Obmedzte upozornenia na vytvorenie a zmeny na vaše <strong>obľúbené súbory</strong> <em>(Len streamy)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "You created %1$s" : "Vytvorili ste %1$s",
    "%2$s created %1$s" : "%2$s vytvoril %1$s",
    "%1$s was created in a public folder" : "%1$s vytvorený vo verejnom priečinku",
    "You changed %1$s" : "Zmenili ste %1$s",
    "%2$s changed %1$s" : "%2$s zmenil %1$s",
    "You deleted %1$s" : "Bol zmazaný %1$s",
    "%2$s deleted %1$s" : "%2$s zmazal %1$s",
    "You restored %1$s" : "Bol obnovený %1$s",
    "%2$s restored %1$s" : "%2$s obnovil %1$s",
    "Changed by %2$s" : "Zmenené používateľom %2$s",
    "Deleted by %2$s" : "Vymazané používateľom %2$s",
    "Restored by %2$s" : "Obnovené používateľom %2$s",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "File handling" : "Nastavenie správania sa k súborom",
    "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
    "max. possible: " : "najväčšie možné:",
    "Save" : "Uložiť",
    "Settings" : "Nastavenia",
    "Show hidden files" : "Zobraziť skryté súbory",
    "WebDAV" : "WebDAV",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "No favorites" : "Žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Not enough free space" : "Nedostatok voľného miesta"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
